package ur_rna.Utilities;

import java.lang.reflect.Method;
import java.util.Collection;

/**
 * Provides information on the current running application.
 */
public class AppInfo {
    private static Class<?> mainClass;
    private static String appName;
    private static String appTitle;
    private static Version appVersion;
    private static AppInfoProvider provider;
    private static boolean providerFailed;

    public static String getAppTitle() {
        if (appTitle != null) return appTitle;

        appTitle = System.getenv("JAVA_APP_TITLE");
        if (appTitle != null) return appTitle;
        AppInfoProvider p = getProvider();
        if (p != null)
            appTitle = p.getAppTitle();
        if (appTitle != null) return appTitle;
        Class<?> main = getMainClass();
        if (main != null)
            appTitle = main.getSimpleName();
        if (appTitle == null)
            appTitle = "Unknown";
        return appTitle;
    }
    public static String getAppName() {
        if (appName != null) return appName;

        appName = System.getenv("JAVA_APP_NAME");
        if (appName != null) return appName;
        AppInfoProvider p = getProvider();
        if (p != null)
            appName = p.getAppName();
        if (appName != null) return appName;
        Class<?> main = getMainClass();
        if (main != null)
            appName = main.getSimpleName();
        if (appName == null)
            appName = "Unknown";
        return appName;
    }
    public static Version getAppVersion() {
        if (appVersion != null) return appVersion;

        String sver = System.getenv("JAVA_APP_VERSION");
        if (sver != null && !sver.isEmpty())
            appVersion = new Version(sver);
        if (appVersion != null) return appVersion;
        AppInfoProvider p = getProvider();
        if (p != null)
            appVersion = p.getAppVersion();
        if (appVersion != null) return appVersion;
        appVersion = new Version("0.0");
        return appVersion;
    }

    public static void setAppName(String name) { appName = name; }
    public static void setAppTitle(String title) { appTitle = title; }
    public static void setProvider(AppInfoProvider p) { provider = p; }
    public static void setMainClass(Class<?> c) { mainClass = c; }

    private static AppInfoProvider getProvider() {
        if (provider != null) return provider;
        if (providerFailed) return null; //failed already. do not re-attempt.

        Class<?> main = getMainClass();
        if (main == null) {
            providerFailed = true;
            return null;
        }

        try {
            Method m = main.getMethod("getAppInfo");
            return provider = (AppInfoProvider)m.invoke(null);
        } catch (Exception ex) {
            // failed.
            providerFailed = true;
            return null;
        }
    }

    public static Class<?> getMainClass() {
        if (mainClass != null)
            return mainClass;

        Collection<StackTraceElement[]> stacks = Thread.getAllStackTraces().values();
        for (StackTraceElement[] currStack : stacks) {
            if (currStack.length==0)
                continue;
            StackTraceElement lastElem = currStack[currStack.length - 1];
            if (lastElem.getMethodName().equals("main")) {
                try {
                    String mainClassName = lastElem.getClassName();
                    mainClass = Class.forName(mainClassName);
                    return mainClass;
                } catch (ClassNotFoundException e) {
                    // bad class name in line containing main?!
                    // shouldn't happen
                    e.printStackTrace();
                }
            }
        }
        return null;
    }

    public interface AppInfoProvider {
        String getAppTitle();
        String getAppName();
        Version getAppVersion();
    }
}
